@@ -89,7 +89,7 @@ def xin2pbn(src_url, output):
     src = Template(template.decode('utf-8'))
     result = src.safe_substitute(all)
     output = output + ".pbn"
-    with io.open(output, "w", encoding="utf-8") as text_file:
+    with open(output, "w", encoding="utf-8") as text_file:
         print("write to file %s" % output)
         text_file.write(result)
 
@@ -113,14 +113,14 @@ def check_file(file):
     filename = os.path.splitext(os.path.basename(file))[0]
     urls = get_xinruiurl(file)
     for index, url in enumerate(urls):
-        pbn_file="%s/%s-%02d" % (dir,filename, index + 1)
+        pbn_file=os.path.join(dir,"%s-%02d" % (filename, index + 1))
         xin2pbn(url.decode("utf-8"), pbn_file)
     # combine together
-    outfilename = "%s/%s.pbn" % (dir,filename)
+    outfilename = os.path.join(dir,filename + ".pbn")
     with open(outfilename, 'wb') as outfile:
         print("write all to one file %s" % outfilename)
         for index, url in enumerate(urls):
-            pbn_file="%s/%s-%02d.pbn" % (dir,filename, index + 1)
+            pbn_file=os.path.join(dir,"%s-%02d.pbn" % (filename, index + 1))
             with open(pbn_file, 'rb') as readfile:
                 shutil.copyfileobj(readfile, outfile)
 
